@@ -19,7 +19,7 @@
 """
 Module for communication with gvmd
 """
-from typing import Any, Optional, Callable
+from typing import Any, Optional, Callable, Union
 
 from gvm.errors import GvmError
 
@@ -28,11 +28,16 @@ from gvm.protocols.base import GvmProtocol, GvmConnection
 from gvm.protocols.gmpv7 import Gmp as Gmpv7
 from gvm.protocols.gmpv8 import Gmp as Gmpv8
 from gvm.protocols.gmpv9 import Gmp as Gmpv9
+from gvm.protocols.gmpv208 import Gmp as Gmpv208
 
 from gvm.transforms import EtreeCheckCommandTransform
 
 from gvm.xml import XmlCommand
 
+SUPPORTED_GMP_VERSIONS = Union[  # pylint: disable=invalid-name
+    Gmpv7, Gmpv8, Gmpv9, Gmpv208
+]
+
 
 class Gmp(GvmProtocol):
     """Dynamically select supported GMP protocol of the remote manager daemon.
@@ -75,7 +80,8 @@ class Gmp(GvmProtocol):
         super().__init__(connection, transform=EtreeCheckCommandTransform())
         self._gmp_transform = transform
 
-    def __enter__(self):
+    def determine_remote_gmp_version(self) -> str:
+        """Determine the supported GMP version of the remote daemon"""
         self.connect()
         resp = self._send_xml_command(XmlCommand("get_version"))
         self.disconnect()
@@ -87,22 +93,33 @@ class Gmp(GvmProtocol):
                 'version information.'
             )
 
-        version = version_el.text
-        major_version = int(version[0])
+        return version_el.text
 
+    def determine_supported_gmp(self) -> SUPPORTED_GMP_VERSIONS:
+        """Determine supported GMP version of the remote daemon and return a
+        corresponding Gmp class instance
+        """
+        version = self.determine_remote_gmp_version()
+        major_version = int(version.split('.')[0])
         if major_version == 7:
             gmp_class = Gmpv7
         elif major_version == 8:
             gmp_class = Gmpv8
-        elif major_version >= 9:
+        elif major_version == 9:
             gmp_class = Gmpv9
+        elif major_version >= 20:
+            gmp_class = Gmpv208
         else:
             raise GvmError(
                 'Remote manager daemon uses an unsupported version of GMP. '
                 'The GMP version was {}.'.format(version)
             )
 
-        gmp = gmp_class(self._connection, transform=self._gmp_transform)
+        return gmp_class(self._connection, transform=self._gmp_transform)
+
+    def __enter__(self):
+        gmp = self.determine_supported_gmp()
+
         gmp.connect()
 
         return gmp
