@@ -65,7 +65,7 @@ __all__ = [
 
 
 class AlertEvent(Enum):
-    """ Enum for alert event types """
+    """Enum for alert event types """
 
     TASK_RUN_STATUS_CHANGED = 'Task run status changed'
     UPDATED_SECINFO_ARRIVED = 'Updated SecInfo arrived'
@@ -75,7 +75,7 @@ class AlertEvent(Enum):
 def get_alert_event_from_string(
     alert_event: Optional[str],
 ) -> Optional[AlertEvent]:
-    """ Convert an alert event string into a AlertEvent instance """
+    """Convert an alert event string into a AlertEvent instance """
     if not alert_event:
         return None
 
@@ -96,7 +96,7 @@ def get_alert_event_from_string(
 
 
 class AlertCondition(Enum):
-    """ Enum for alert condition types """
+    """Enum for alert condition types """
 
     ALWAYS = 'Always'
     SEVERITY_AT_LEAST = 'Severity at least'
@@ -107,7 +107,7 @@ class AlertCondition(Enum):
 def get_alert_condition_from_string(
     alert_condition: Optional[str],
 ) -> Optional[AlertCondition]:
-    """ Convert an alert condition string into a AlertCondition instance """
+    """Convert an alert condition string into a AlertCondition instance """
     if not alert_condition:
         return None
 
@@ -122,6 +122,9 @@ def get_alert_condition_from_string(
     if alert_condition == 'filter count at least':
         return AlertCondition.FILTER_COUNT_AT_LEAST
 
+    if alert_condition == 'severity at least':
+        return AlertCondition.SEVERITY_AT_LEAST
+
     raise InvalidArgument(
         argument='alert_condition',
         function=get_alert_condition_from_string.__name__,
@@ -129,7 +132,7 @@ def get_alert_condition_from_string(
 
 
 class AlertMethod(Enum):
-    """ Enum for alert method type"""
+    """Enum for alert method type"""
 
     SCP = "SCP"
     SEND = "Send"
@@ -146,7 +149,7 @@ class AlertMethod(Enum):
 def get_alert_method_from_string(
     alert_method: Optional[str],
 ) -> Optional[AlertMethod]:
-    """ Convert an alert method string into a AlertCondition instance """
+    """Convert an alert method string into a AlertCondition instance """
     if not alert_method:
         return None
 
@@ -170,17 +173,18 @@ def get_alert_method_from_string(
         raise InvalidArgument(
             argument='alert_method',
             function=get_alert_method_from_string.__name__,
-        )
+        ) from None
 
 
 class AliveTest(Enum):
-    """ Enum for choosing an alive test """
+    """Enum for choosing an alive test """
 
     SCAN_CONFIG_DEFAULT = 'Scan Config Default'
     ICMP_PING = 'ICMP Ping'
     TCP_ACK_SERVICE_PING = 'TCP-ACK Service Ping'
     TCP_SYN_SERVICE_PING = 'TCP-SYN Service Ping'
-    APR_PING = 'ARP Ping'
+    ARP_PING = 'ARP Ping'
+    APR_PING = 'ARP Ping'  # Alias for ARP_PING
     ICMP_AND_TCP_ACK_SERVICE_PING = 'ICMP & TCP-ACK Service Ping'
     ICMP_AND_ARP_PING = 'ICMP & ARP Ping'
     TCP_ACK_SERVICE_AND_ARP_PING = 'TCP-ACK Service & ARP Ping'
@@ -193,7 +197,7 @@ class AliveTest(Enum):
 def get_alive_test_from_string(
     alive_test: Optional[str],
 ) -> Optional[AliveTest]:
-    """ Convert an alive test string into a AliveTest instance """
+    """Convert an alive test string into a AliveTest instance """
     if not alive_test:
         return None
 
@@ -212,7 +216,7 @@ def get_alive_test_from_string(
         return AliveTest.TCP_SYN_SERVICE_PING
 
     if alive_test == 'arp ping':
-        return AliveTest.APR_PING
+        return AliveTest.ARP_PING
 
     if alive_test == 'icmp & tcp-ack service ping':
         return AliveTest.ICMP_AND_TCP_ACK_SERVICE_PING
@@ -235,7 +239,7 @@ def get_alive_test_from_string(
 
 
 class AssetType(Enum):
-    """" Enum for asset types """
+    """"Enum for asset types """
 
     OPERATING_SYSTEM = 'os'
     HOST = 'host'
@@ -255,7 +259,7 @@ def get_asset_type_from_string(
     except KeyError:
         raise InvalidArgument(
             argument='asset_type', function=get_asset_type_from_string.__name__
-        )
+        ) from None
 
 
 class CredentialFormat(Enum):
@@ -280,11 +284,11 @@ def get_credential_format_from_string(
         raise InvalidArgument(
             argument='credential_format',
             function=get_credential_format_from_string.__name__,
-        )
+        ) from None
 
 
 class CredentialType(Enum):
-    """ Enum for credential types """
+    """Enum for credential types """
 
     CLIENT_CERTIFICATE = 'cc'
     SNMP = 'snmp'
@@ -295,8 +299,7 @@ class CredentialType(Enum):
 def get_credential_type_from_string(
     credential_type: Optional[str],
 ) -> Optional[CredentialType]:
-    """ Convert a credential type string into a CredentialType instance
-    """
+    """Convert a credential type string into a CredentialType instance"""
     if not credential_type:
         return None
 
@@ -306,11 +309,11 @@ def get_credential_type_from_string(
         raise InvalidArgument(
             argument='credential_type',
             function=get_credential_type_from_string.__name__,
-        )
+        ) from None
 
 
 class EntityType(Enum):
-    """ Enum for entity types """
+    """Enum for entity types """
 
     AGENT = "agent"
     ALERT = "alert"
@@ -347,7 +350,7 @@ class EntityType(Enum):
 def get_entity_type_from_string(
     entity_type: Optional[str],
 ) -> Optional[EntityType]:
-    """ Convert a entity type string to an actual EntityType instance
+    """Convert a entity type string to an actual EntityType instance
 
     Arguments:
         entity_type: Resource type string to convert to a EntityType
@@ -366,11 +369,11 @@ def get_entity_type_from_string(
         raise InvalidArgument(
             argument='entity_type',
             function=get_entity_type_from_string.__name__,
-        )
+        ) from None
 
 
 class FeedType(Enum):
-    """ Enum for feed types """
+    """Enum for feed types """
 
     NVT = "NVT"
     CERT = "CERT"
@@ -378,8 +381,7 @@ class FeedType(Enum):
 
 
 def get_feed_type_from_string(feed_type: Optional[str]) -> Optional[FeedType]:
-    """ Convert a feed type string into a FeedType instance
-    """
+    """Convert a feed type string into a FeedType instance"""
     if not feed_type:
         return None
 
@@ -388,11 +390,11 @@ def get_feed_type_from_string(feed_type: Optional[str]) -> Optional[FeedType]:
     except KeyError:
         raise InvalidArgument(
             argument='feed_type', function=get_feed_type_from_string.__name__
-        )
+        ) from None
 
 
 class FilterType(Enum):
-    """ Enum for filter types """
+    """Enum for filter types """
 
     AGENT = "agent"
     ALERT = "alert"
@@ -422,7 +424,7 @@ class FilterType(Enum):
 def get_filter_type_from_string(
     filter_type: Optional[str],
 ) -> Optional[FilterType]:
-    """ Convert a filter type string to an actual FilterType instance
+    """Convert a filter type string to an actual FilterType instance
 
     Arguments:
         filter_type: Filter type string to convert to a FilterType
@@ -445,7 +447,7 @@ def get_filter_type_from_string(
         raise InvalidArgument(
             argument='filter_type',
             function=get_filter_type_from_string.__name__,
-        )
+        ) from None
 
 
 class HostsOrdering(Enum):
@@ -459,7 +461,7 @@ class HostsOrdering(Enum):
 def get_hosts_ordering_from_string(
     hosts_ordering: Optional[str],
 ) -> Optional[HostsOrdering]:
-    """ Convert a hosts ordering string to an actual HostsOrdering instance
+    """Convert a hosts ordering string to an actual HostsOrdering instance
 
     Arguments:
         hosts_ordering: Host ordering string to convert to a HostsOrdering
@@ -472,7 +474,7 @@ def get_hosts_ordering_from_string(
         raise InvalidArgument(
             argument='hosts_ordering',
             function=get_hosts_ordering_from_string.__name__,
-        )
+        ) from None
 
 
 class InfoType(Enum):
@@ -488,7 +490,7 @@ class InfoType(Enum):
 
 
 def get_info_type_from_string(info_type: Optional[str]) -> Optional[InfoType]:
-    """ Convert a info type string to an actual InfoType instance
+    """Convert a info type string to an actual InfoType instance
 
     Arguments:
         info_type: Info type string to convert to a InfoType
@@ -500,7 +502,7 @@ def get_info_type_from_string(info_type: Optional[str]) -> Optional[InfoType]:
     except KeyError:
         raise InvalidArgument(
             argument='info_type', function=get_info_type_from_string.__name__
-        )
+        ) from None
 
 
 class PermissionSubjectType(Enum):
@@ -514,7 +516,7 @@ class PermissionSubjectType(Enum):
 def get_permission_subject_type_from_string(
     subject_type: Optional[str],
 ) -> Optional[PermissionSubjectType]:
-    """ Convert a permission subject type string to an actual
+    """Convert a permission subject type string to an actual
     PermissionSubjectType instance
 
     Arguments:
@@ -530,7 +532,7 @@ def get_permission_subject_type_from_string(
         raise InvalidArgument(
             argument='subject_type',
             function=get_permission_subject_type_from_string.__name__,
-        )
+        ) from None
 
 
 class PortRangeType(Enum):
@@ -543,7 +545,7 @@ class PortRangeType(Enum):
 def get_port_range_type_from_string(
     port_range_type: Optional[str],
 ) -> Optional[PortRangeType]:
-    """ Convert a port range type string to an actual PortRangeType instance
+    """Convert a port range type string to an actual PortRangeType instance
 
     Arguments:
         port_range_type: Port range type string to convert to a PortRangeType
@@ -557,7 +559,7 @@ def get_port_range_type_from_string(
         raise InvalidArgument(
             argument='port_range_type',
             function=get_port_range_type_from_string.__name__,
-        )
+        ) from None
 
 
 class ScannerType(Enum):
@@ -572,7 +574,7 @@ class ScannerType(Enum):
 def get_scanner_type_from_string(
     scanner_type: Optional[str],
 ) -> Optional[ScannerType]:
-    """ Convert a scanner type string to an actual ScannerType instance
+    """Convert a scanner type string to an actual ScannerType instance
 
     Arguments:
         scanner_type: Scanner type string to convert to a ScannerType
@@ -621,8 +623,7 @@ class SnmpAuthAlgorithm(Enum):
 def get_snmp_auth_algorithm_from_string(
     algorithm: Optional[str],
 ) -> Optional[SnmpAuthAlgorithm]:
-    """ Convert a SNMP auth algorithm string into a SnmpAuthAlgorithm instance
-    """
+    """Convert a SNMP auth algorithm string into a SnmpAuthAlgorithm instance"""
     if not algorithm:
         return None
 
@@ -632,7 +633,7 @@ def get_snmp_auth_algorithm_from_string(
         raise InvalidArgument(
             argument='algorithm',
             function=get_snmp_auth_algorithm_from_string.__name__,
-        )
+        ) from None
 
 
 class SnmpPrivacyAlgorithm(Enum):
@@ -645,8 +646,8 @@ class SnmpPrivacyAlgorithm(Enum):
 def get_snmp_privacy_algorithm_from_string(
     algorithm: Optional[str],
 ) -> Optional[SnmpPrivacyAlgorithm]:
-    """ Convert a SNMP privacy algorithm string into a SnmpPrivacyAlgorithm
-        instance
+    """Convert a SNMP privacy algorithm string into a SnmpPrivacyAlgorithm
+    instance
     """
     if not algorithm:
         return None
@@ -657,7 +658,7 @@ def get_snmp_privacy_algorithm_from_string(
         raise InvalidArgument(
             argument='algorithm',
             function=get_snmp_privacy_algorithm_from_string.__name__,
-        )
+        ) from None
 
 
 class SeverityLevel(Enum):
@@ -684,7 +685,7 @@ def get_severity_level_from_string(
         raise InvalidArgument(
             argument='severity_level',
             function=get_severity_level_from_string.__name__,
-        )
+        ) from None
 
 
 class TimeUnit(Enum):
@@ -711,4 +712,4 @@ def get_time_unit_from_string(time_unit: Optional[str]) -> Optional[TimeUnit]:
         raise InvalidArgument(
             argument='severity_level',
             function=get_severity_level_from_string.__name__,
-        )
+        ) from None
