@@ -104,10 +104,6 @@ class Gmpv9CreateAgentTestCase(GmpCreateAgentTestCase, Gmpv9TestCase):
     pass
 
 
-class Gmpv9CreateAlertTestCase(GmpCreateAlertTestCase, Gmpv9TestCase):
-    pass
-
-
 class Gmpv9CreateContainerTaskCommandTestCase(
     GMPCreateContainerTaskCommandTestCase, Gmpv9TestCase
 ):
@@ -462,10 +458,6 @@ class Gmpv9ModifyAgentTestCase(GmpModifyAgentTestCase, Gmpv9TestCase):
     pass
 
 
-class Gmpv9ModifyAlertTestCase(GmpModifyAlertTestCase, Gmpv9TestCase):
-    pass
-
-
 class Gmpv9ModifyAssetTestCase(GmpModifyAssetTestCase, Gmpv9TestCase):
     pass
 
